<?php
declare(strict_types=1);

namespace IntiTest\Wp\Provider\Mock;

use Inti\Provider\Query\QueryTrait;
use Inti\Wp\Provider\Post\ProviderInterface;
use Inti\Wp\Provider\Type\WpTypeInterface;

use function array_combine;
use function array_map;
use function in_array;
use function preg_match;
use function preg_quote;

/**
 * Class PostProvider
 *
 * @package IntiTest\Wp\Provider\Mock
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-wp-provider
 */
final class PostProvider extends PostMetadataProvider implements ProviderInterface
{
    use QueryTrait;

    private array $items = [
        [1, 'First post', 'first-post'],
        [2, 'Second post', 'second-post'],
        [3, 'Third post', 'third-post'],
    ];

    private array $fields = [
        'ID',
        'post_title',
        'post_name',
    ];

    public function getProvidedType(): WpTypeInterface
    {
        return CustomPostType::instance();
    }

    public function getCount(): int
    {
        return count($this->getItems());
    }

    public function getItem(): ?array
    {
        return $this->getItems()[0] ?? null;
    }

    public function getItems(): array
    {
        $items = [];

        foreach ($this->items as $item) {
            if (isset($this->ids) && !empty($this->ids)) {
                if (in_array($item[0], $this->ids)) {
                    $items[] = $item;
                }
            } else if (isset($this->slugs) && !empty($this->slugs)) {
                if (in_array($item[2], $this->slugs)) {
                    $items[] = $item;
                }
            } else if (isset($this->search) && !empty($this->search)) {
                if (preg_match('/' . preg_quote($this->search, '/') . '/', $item[1])) {
                    $items[] = $item;
                }
            } else {
                $items[] = $item;
            }
        }

        if ($this->offset) {
            $items = array_slice($items, $this->offset);
        }

        if ($this->limit) {
            $items = array_slice($items, 0, $this->limit);
        }

        return array_map(function (array $item) {
            return array_combine($this->fields, $item);
        }, $items);
    }
}
