<?php
declare(strict_types=1);

namespace IntiTest\Wp\Provider\Plugin;

use IntiTest\Wp\Provider\Mock\PostMetadataProvider;
use IntiTest\Wp\Provider\Mock\TermMetadataProvider;
use IntiTest\Wp\Provider\TestCaseTrait;
use PHPUnit\Framework\TestCase;

use function get_post_meta;
use function get_term_meta;

/**
 * Class ProvideMetadataTest
 *
 * @package IntiTest\Wp\Provider\Plugin
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-wp-provider
 *
 * @runTestsInSeparateProcesses
 */
final class ProvideMetadataTest extends TestCase
{
    use TestCaseTrait;

    protected function setUp(): void
    {
        $this->setUpWordPress();
    }

    public function testCanProvidePostMetadata()
    {
        $this->runApplicationWithProvider(new PostMetadataProvider());

        $this->assertEquals([
            '_meta_key1' => ['meta value 1-1'],
            '_meta_key2' => ['meta value 1-2'],
        ], get_post_meta(1));
    }

    public function testCanProvidePostMetadataForKey()
    {
        $this->runApplicationWithProvider(new PostMetadataProvider());
        $this->assertEquals('meta value 1-1', get_post_meta(1, '_meta_key1', true));
    }

    public function testCanProvideTermMetadata()
    {
        $this->runApplicationWithProvider(new TermMetadataProvider());

        $this->assertEquals([
            '_meta_key1' => ['meta value 1-1'],
            '_meta_key2' => ['meta value 1-2'],
        ], get_term_meta(1));
    }

    public function testCanProvideTermMetadataForKey()
    {
        $this->runApplicationWithProvider(new TermMetadataProvider());
        $this->assertEquals('meta value 1-1', get_term_meta(1, '_meta_key1', true));
    }
}
