<?php
declare(strict_types=1);

namespace IntiTest\Wp\Provider\Plugin;

use IntiTest\Wp\Provider\Mock;
use IntiTest\Wp\Provider\TestCaseTrait;
use PHPUnit\Framework\TestCase;
use WP_Taxonomy;

use function get_categories;
use function get_terms;
use function wp_count_terms;

/**
 * Class ProvideTermsTest
 *
 * @package IntiTest\Wp\Provider\Plugin
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-wp-provider
 *
 * @runTestsInSeparateProcesses
 */
final class ProvideTermsTest extends TestCase
{
    use TestCaseTrait;

    protected function setUp(): void
    {
        $this->setUpWordPress();
    }

    public function testWillRegisterCustomTaxonomy()
    {
        $this->runApplicationWithProvider(new Mock\TermProvider());

        $taxonomy = get_taxonomy('custom_taxonomy');
        $this->assertInstanceOf(WP_Taxonomy::class, $taxonomy);

        $this->assertEquals('Custom Terms', $taxonomy->label);
        $this->assertEquals('some description', $taxonomy->description);
        $this->assertFalse($taxonomy->public);
        $this->assertEquals(['custom_post'], $taxonomy->object_type);
    }

    public function testCanProvideTerms()
    {
        $this->runApplicationWithProvider(new Mock\TermProvider());

        $terms = get_terms([
            'taxonomy' => 'custom_taxonomy'
        ]);

        $this->assertCount(3, $terms);
    }

    public function testCanGetTermsByIds()
    {
        $this->runApplicationWithProvider(new Mock\TermProvider());

        $terms = get_terms([
            'include' => [100000002],
            'taxonomy' => 'custom_taxonomy',
        ]);

        $this->assertCount(1, $terms);
        $this->assertEquals('Second term', $terms[0]->name);
    }

    public function testCanCountTerms()
    {
        $this->runApplicationWithProvider(new Mock\TermProvider());

        $count = wp_count_terms([
            'taxonomy' => 'custom_taxonomy',
        ]);

        $this->assertEquals(3, $count);
    }

    public function testCanProvideTermsToExistingTaxonomies()
    {
        $this->runApplicationWithProvider(new Mock\OverrideTermProvider());

        $terms = get_terms([
            'taxonomy' => 'category',
        ]);

        $this->assertCount(3, $terms);
    }

    public function testCanGetCategories()
    {
        $this->runApplicationWithProvider(new Mock\OverrideTermProvider());

        $categories = get_categories([
            'parent' => 0,
            'hide_empty' => 0,
            'hierarchical' => 1,
            'taxonomy' => 'category',
            'pad_counts' => 1,
        ]);

        $this->assertCount(3, $categories);
    }
}
