<?php
declare(strict_types=1);

namespace IntiTest\Wp\Provider;

use Inti\Provider\ProviderInterface;
use Inti\Provider\Service\ProviderManagerInterface;
use Inti\Test\TestCase\ApplicationTestTrait;
use Inti\Wp\Provider\ConfigProvider;
use Inti\Wp\Provider\Service\IdManager;
use Laminas\Stdlib\ArrayUtils;
use Psr\Http\Message\ResponseInterface;

use function define;
use function defined;
use function delete_option;
use function function_exists;
use function realpath;

/**
 * Trait TestCaseTrait
 *
 * @package IntiTest\Wp\Provider
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-wp-provider
 */
trait TestCaseTrait
{
    use ApplicationTestTrait;

    protected array $providers = [
        \Inti\Db\ConfigProvider::class,
        \Inti\Provider\ConfigProvider::class,
        \Inti\Wp\Middleware\ConfigProvider::class,
        \Inti\Wp\Plugin\ConfigProvider::class,
        ConfigProvider::class,
    ];

    protected array $config = [
        'db_connections' => [
            'default' => [
                'host' => 'localhost',
                'user' => 'root',
                'password' => 'password',
                'dbname' => 'inti_wp',
            ],
        ],
    ];

    protected function setUpWordPress()
    {
        if (!defined('ABSPATH')) {
            define('ABSPATH', realpath(__DIR__ . '/../wordpress') . '/');
        }

        if (!defined('WP_DEBUG')) {
            define('WP_DEBUG', true);
        }


    }

    protected function tearDown(): void
    {
        if (function_exists('delete_option')) {
            delete_option(IdManager::OPTION_NAME);
        }
    }

    protected function createProviderManager(array $config = []): ProviderManagerInterface
    {
        $container = $this->createContainer($config);
        return $container->get(ProviderManagerInterface::class);
    }

    public function runApplicationWithProvider(ProviderInterface $provider, array $config = []): ResponseInterface
    {
        return $this->runApplication(ArrayUtils::merge($config, [
            'wp' => [
                'providers' => [$provider],
            ],
        ]));
    }
}
